@@ -35,33 +35,44 @@ def _list_model_versions(model_versions):
 
 
 def _create_local_version_path(
-    *, model_name, new_model_version_id, previous_model_version_id, new_version
+    *, model_name, previous_model_version, new_model_version
 ):
     log.action("Copying existing model notebook...")
 
     cwd = Path.cwd()
-    os.makedirs(f"{cwd}/models/{model_name}/{new_model_version_id}")
+    os.makedirs(f"{cwd}/models/{model_name}/{new_model_version['name']}")
+    os.makedirs(f"{cwd}/handlers/{model_name}/{new_model_version['name']}")
 
+    # copy notebook
     notebook_to_copy = Path(
-        f"{cwd}/models/{model_name}/{previous_model_version_id}/notebook.ipynb"
+        f"{cwd}/models/{model_name}/{previous_model_version['name']}/notebook.ipynb"
     )
     new_notebook = Path(
-        f"{cwd}/models/{model_name}/{new_model_version_id}/notebook.ipynb"
+        f"{cwd}/models/{model_name}/{new_model_version['name']}/notebook.ipynb"
     )
 
     shutil.copy(notebook_to_copy, new_notebook)
     with open(new_notebook) as f_in:
-        _text = f_in.read().replace(previous_model_version_id, new_model_version_id)
+        _text = f_in.read().replace(
+            previous_model_version["id"], new_model_version["id"]
+        )
 
     with open(new_notebook, "w") as f_out:
         f_out.write(_text)
 
+    # copy handler and test event
+    shutil.copytree(
+        f"{cwd}/handlers/{model_name}/{previous_model_version['name']}",
+        f"{cwd}/handlers/{model_name}/{new_model_version['name']}",
+        dirs_exist_ok=True,
+    )
+
 
 def _commit_model_version(*, model_name, model_version_id, model_version_name):
     cwd = Path.cwd()
     repo = Repo.init(cwd)
-    repo.git.add([f"models/{model_name}/{model_version_id}"])
-    repo.git.add([f"handlers/{model_name}/*"])
+    repo.git.add([f"models/{model_name}/{model_version_name}"])
+    repo.git.add([f"handlers/{model_name}/{model_version_name}"])
     repo.index.commit(f"created model version: {model_name}/{model_version_name}")
 
     try:
@@ -114,6 +125,8 @@ def checkout_model_version(model_name, version_name=None):
         f"Current model version is: {model_version['name']} <{model_version_id}>"
     )
 
+    previous_model_version = model_version
+
     # if a version name was specified, check if a version with that name exists
     if version_name is not None:
 
@@ -138,9 +151,8 @@ def checkout_model_version(model_name, version_name=None):
 
             _create_local_version_path(
                 model_name=model_name,
-                new_model_version_id=model_version_id_to_checkout,
-                previous_model_version_id=model_version_id,
-                new_version=model_version,
+                previous_model_version=previous_model_version,
+                new_model_version=model_version,
             )
 
             _commit_model_version(
