@@ -7,7 +7,6 @@ import socket
 import ast
 import subprocess
 import dateutil.parser
-import datetime
 
 from select import select
 from slai.clients.cli import get_cli_client
@@ -55,7 +54,7 @@ def _decode_string(s):
     initial_length = len(s)
     for frame in frame_indices:
         offset = len(s) - initial_length
-        del s[frame[0] + offset : frame[1] + offset]
+        del s[frame[0] + offset : frame[1] + offset]  # noqa
 
     return s.decode("utf-8", "ignore")
 
@@ -78,8 +77,8 @@ class DockerClient:
         self.cli_client = get_cli_client()
         self.cli_version = self.cli_client.get_cli_version()
 
-        self.earliest_image_tag_time = dateutil.parser.isoparse(
-            self.cli_version["earliest_docker_image_tag_time"]
+        self.earliest_image_creation_time = dateutil.parser.isoparse(
+            self.cli_version["earliest_docker_image_creation_time"]
         )
 
         try:
@@ -102,11 +101,11 @@ class DockerClient:
             self.project_container = containers[0]
             self.project_container_id = self.project_container.id
             self.host_port = self.project_container.ports["8888/tcp"][0]["HostPort"]
-            self.last_tag_time = dateutil.parser.isoparse(
-                self.project_container.image.attrs["Metadata"]["LastTagTime"]
-            )
 
-            if self.last_tag_time < self.earliest_image_tag_time:
+            self.image_creation_time = dateutil.parser.isoparse(
+                self.project_container.image.attrs["Created"]
+            )
+            if self.image_creation_time < self.earliest_image_creation_time:
                 log.warn(
                     "Project container is out of date, please update to the latest image with: `docker-compose pull`"  # noqa
                 )
